@@ -1,7 +1,6 @@
-try:
-    from staticfiles.storage import staticfiles_storage
-except ImportError:
-    from django.contrib.staticfiles.storage import staticfiles_storage  # noqa
+from __future__ import unicode_literals
+
+from django.contrib.staticfiles.storage import staticfiles_storage
 
 from django import template
 from django.template.loader import render_to_string
@@ -29,7 +28,7 @@ class CompressedCSSNode(template.Node):
         except PackageNotFound:
             return ''  # fail silently, do not return anything if an invalid group is specified
 
-        if settings.PIPELINE:
+        if not settings.DEBUG:
             return self.render_css(package, package.output_filename)
         else:
             paths = self.packager.compile(package.paths)
@@ -65,7 +64,7 @@ class CompressedJSNode(template.Node):
         except PackageNotFound:
             return ''  # fail silently, do not return anything if an invalid group is specified
 
-        if settings.PIPELINE:
+        if not settings.DEBUG:
             return self.render_js(package, package.output_filename)
         else:
             paths = self.packager.compile(package.paths)
@@ -99,7 +98,7 @@ def compressed_css(parser, token):
     try:
         tag_name, name = token.split_contents()
     except ValueError:
-        raise template.TemplateSyntaxError, '%r requires exactly one argument: the name of a group in the PIPELINE_CSS setting' % token.split_contents()[0]
+        raise template.TemplateSyntaxError('%r requires exactly one argument: the name of a group in the PIPELINE_CSS setting' % token.split_contents()[0])
     return CompressedCSSNode(name)
 compressed_css = register.tag(compressed_css)
 
@@ -108,6 +107,6 @@ def compressed_js(parser, token):
     try:
         tag_name, name = token.split_contents()
     except ValueError:
-        raise template.TemplateSyntaxError, '%r requires exactly one argument: the name of a group in the PIPELINE_JS setting' % token.split_contents()[0]
+        raise template.TemplateSyntaxError('%r requires exactly one argument: the name of a group in the PIPELINE_JS setting' % token.split_contents()[0])
     return CompressedJSNode(name)
 compressed_js = register.tag(compressed_js)
